@@ -9,11 +9,12 @@ import random, gobject, os.path, signal, sys, time
 import dbus, dbus.service
 from dbus.mainloop.glib import DBusGMainLoop
 from advpowcommon.util.loader import ClassLoader
+from advpowcommon.util.device import device
 
 class apm(dbus.service.Object):
 
   appname = 'Advanced Power Monitor'
-  version = '0.5.2-7'
+  version = '0.5.2-8'
   iface = "ru.spirit.advanced_power_monitor"
   opath = "/ru/spirit/advanced_power_monitor"
   wrappers_root = 'wrappers'
@@ -21,6 +22,7 @@ class apm(dbus.service.Object):
 
   def __init__(self):
     print '%s %s' % (self.appname, self.version)
+    print '%s\n' % (device.get_property('OSSO_VERSION'))
     self.__bus = dbus.SystemBus(mainloop = DBusGMainLoop(), private = True)
     dbus.service.Object.__init__(self, dbus.service.BusName(self.iface, self.__bus), self.opath)
 
@@ -90,6 +92,7 @@ class apm(dbus.service.Object):
     signal.signal(signal.SIGTERM, self.__cleanup)
     self.__working = True
     self.update_info()
+    print '\nLOADED'
 
   def _cleanup(self):
     self.__cleanup()
@@ -151,9 +154,10 @@ class apm(dbus.service.Object):
 #Wrappers routine
   def __init_wrappers(self):
     for key in self.__wrappers:
+      print '\nLOADING %s' % (key)
       self.__check_wrapper(key)
       self.change_wrapper(key, self.get_available_wrappers(key)[0])
-      print 'USING:\t%s\n' % str(self.__wrappers[key]['name'])
+      print '[U] %s\n' % str(self.__wrappers[key]['name'])
 
   @dbus.service.method(dbus_interface='ru.spirit.advanced_power_monitor.request', out_signature='as')
   def get_wrappers_types(self):
@@ -172,10 +176,10 @@ class apm(dbus.service.Object):
       name = wrapper.get_name()
       if wrapper.is_available():
         self.__wrappers[key]['available'][name] = ind
-        print 'LOADED:\t%s' % (name)
+        print '[L] %s' % (name)
         ind += 1
       else:
-        print 'FAILED:\t%s' % (name)
+        print '[F] %s' % (name)
       wrapper._cleanup()
       del wrapper
 
@@ -191,6 +195,7 @@ class apm(dbus.service.Object):
         self.__wrappers[key]['object']._cleanup()
       self.__wrappers[key]['name'] = new_wrapper
       wrapper_object._cleanup()#end_init()
+
       self.__wrappers[key]['object'] = self.__wrappers[key]['list'][self.__wrappers[key]['available'][new_wrapper]](self.__bus)
       self.__init_wrapper(key)
       if key == 'battery':
